@@ -7,10 +7,9 @@ DEFAULT_GRPC_PORT = 443
 DEFAULT_TLS = True
 
 # gRPC metadata constants
-AUTHORIZATION_HEADER_KEY = "authorization"
+API_KEY_HEADER = "x-api-key"
 COOKIE_HEADER_KEY = "cookie"
 GROUP_HEADER_KEY = "x-group"
-BEARER_PREFIX = "Bearer "
 ACCESS_TOKEN_PREFIX = "AccessToken="
 
 
@@ -18,13 +17,13 @@ def create_auth_metadata(api_key: str, group: str) -> list[tuple[str, str]]:
     """Create authentication metadata for gRPC requests.
 
     Args:
-        api_key: The API key (without Bearer prefix)
+        api_key: The API key
         group: The group resource name in format groups/{group_id}
 
     Returns:
         List of metadata header tuples for authentication
     """
     return [
-        (AUTHORIZATION_HEADER_KEY, f"{BEARER_PREFIX}{api_key}"),
+        (API_KEY_HEADER, api_key),
         (GROUP_HEADER_KEY, group),  # Send full groups/uuid format in header
     ]
